@@ -47,20 +47,27 @@ sub op_load_lvar_to_sb {
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
 }
 
+{
+    package
+        Text::Xslate::PP::Opcode::Guard;
+
+    sub DESTROY { $_[0]->() }
+}
+
 sub op_local_s {
     my($st) = @_;
-    my $key    = $st->pc_arg;
     my $vars   = $st->{vars};
-    my $newval = $st->{sa};
+    my $key    = $st->pc_arg;
+    my $preeminent
+               = exists $vars->{$key};
     my $oldval = delete $vars->{$key};
+    my $newval = $st->{sa};
 
-    require Scope::Guard;
-
-    push @{ $_[0]->{local_stack} ||= [] }, Scope::Guard->new(
-        exists $vars->{$key}
-            ? sub {  $vars->{$key} = $oldval; return }
-            : sub { delete $vars->{$key};     return }
-    );
+    my $cleanup = $preeminent
+        ? sub { $vars->{$key} = $oldval; return }
+        : sub { delete $vars->{$key};    return };
+    push @{ $_[0]->{local_stack} ||= [] },
+        bless($cleanup, 'Text::Xslate::PP::Opcode::Guard');
 
     $vars->{$key} = $newval;
 
@@ -73,12 +80,6 @@ sub op_push {
 }
 
 
-sub op_pop {
-    #
-    goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
-}
-
-
 sub op_pushmark {
     push @{ $_[0]->{ SP } }, [];
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
@@ -180,10 +181,7 @@ sub op_print_raw_s {
 sub op_include {
     my $st = Text::Xslate::PP::tx_load_template( $_[0]->self, $_[0]->{sa} );
 
-    {
-        local $st->{local_stack};
-        Text::Xslate::PP::tx_execute( $st, undef, $_[0]->{vars} );
-    }
+    Text::Xslate::PP::tx_execute( $st, undef, $_[0]->{vars} );
 
     $_[0]->{ output } .= $st->{ output };
 
@@ -276,24 +274,6 @@ sub op_concat {
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
 }
 
-
-sub op_filt {
-    my $arg    = $_[0]->{sb};
-    my $filter = $_[0]->{sa};
-
-    local $@;
-
-    my $ret = eval { $filter->( $arg ) };
-
-    if ( $@ ) {
-        Carp::croak( sprintf("%s\n\t... exception cought on %s", $@, 'filtering') );
-    }
-
-    $_[0]->{sa} = $ret;
-    goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
-}
-
-
 sub op_and {
     if ( $_[0]->{sa} ) {
         goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
